# ##### BEGIN GPL LICENSE BLOCK #####
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# ##### END GPL LICENSE BLOCK #####

# <pep8-80 compliant>
bl_addon_info = {
    'name': '3D View: Armature Layer Names',
    'author': 'Bassam Kurdali',
    'version': '0.1',
    'blender': (2, 5, 3),
    'location': 'View3D > Properties > Armature Layer Names',
    'description': 'Names for Armature Layers',
    'url': 'http://tube.freefac.org',
    'category': '3D View'}

__bpydoc__ = """
Armature Layers

Panel to hide/unhide armature layers with names, useful for riggers and for 
animators.
"""
import bpy



class assign_layer_name(bpy.types.Operator):
    '''Name a layer to a specific Name'''
    bl_idname = "assign_layer_name"
    bl_label = "Assign Layer Name"

    number = bpy.props.IntProperty(name="number", description="layernumber", 
       default=0, min=0, max=31)
       
    layername = bpy.props.StringProperty(name="layername", description="layername")
    
    @classmethod
    def poll( cls, context):
        act = context.active_object
        return act != None and act.type == 'ARMATURE'

    def execute(self, context):
        act = context.active_object.data
        no = self.properties.number
        for key in act["__layers"]:
            if act["__layers"][key] == no:
                act["__layers"].pop(key)
                
        act["__layers"][self.properties.layername]=no
        return {'FINISHED'}

    def invoke(self, context, event):
        wm = context.window_manager
        wm.invoke_props_dialog(self)
        return {'RUNNING_MODAL'}

    def draw(self, context):
        props = self.properties
        layout = self.layout
        layout.prop(props ,"number")
        layout.prop(props ,"layername")
        
        

class armature_layer_names(bpy.types.Panel):
    ''' Named Layer Manager for Armatures '''
    bl_label = "Armature Layer Names"
    bl_space_type = "VIEW_3D"
    bl_region_type = "UI"

    @classmethod
    def poll(cls, context):
        act = context.active_object
        return act != None and act.type == 'ARMATURE'

    def draw(self, context):
        layout = self.layout
        armlayers = context.object.data.layers
        data = context.object.data
        try:
            layers = context.object.data["__layers"]
        except KeyError:
            context.object.data["__layers"]={}
            layers = context.object.data["__layers"]
       
        layerlist = layers.keys()[:]
        layerlist.sort()       
        row = layout.row()
        row.operator("assign_layer_name")
        for layer in layerlist:
            row = layout.row()
            split = row.split()
            col1=split.column()
            col1.prop(data,"layers",index = layers[layer],text = layer)
            col2 = split.column()
            col2.label(str(layers[layer]))
            
            
class switch_bone_layer_pop(bpy.types.Operator):
    ''' popup to switch to only named layers '''
    bl_label = "change bone name layer"
    bl_idname = "pose.switch_bone_layer_pop"
    
    for layer in range(32):
        label = "layer_"+str(layer)
        vars()[label] =bpy.props.BoolProperty(name = label, description =label) 
    test = bpy.props.BoolProperty(name = "testy", description ="test")
        
    @classmethod
    def poll( cls, context):
        return context.mode == 'POSE' or context.mode == 'EDIT_ARMATURE' and context.active_bone != None

    def execute(self, context):
        if context.mode == "EDIT_ARMATURE":
            list = context.selected_bones
        else:
            list = context.selected_pose_bones
        for bone in list:
            bone_layers = context.active_object.data.bones[bone.name].layers
            for layer in range(32):
                label = "layer_"+str(layer)
                bone_layers[layer] = self.properties[label]
        
        return {'FINISHED'}
    
    def invoke(self, context, event):
        wm = context.window_manager
        wm.invoke_props_dialog(self)
        return {'RUNNING_MODAL'}
    
    def draw(self, context):
        layout = self.layout
        act = context.active_object
        layermask = [False for i in range(32)]
        if context.mode == "EDIT_ARMATURE":
            list = context.selected_bones
        else:
            list = context.selected_pose_bones
        for bone in list:
            for i in range(32):
                layermask[i] = layermask[i] or act.data.bones[bone.name].layers[i]
        try:
            layers = act.data["__layers"]
        except KeyError:
            layers = {}
        layerpairs ={ layers[name]:name for name in layers.keys()}
        for a in layerpairs.keys():
            print(layerpairs[a],a)
        
        for layer in range(32):
            label = "layer_"+str(layer) 
            if layer in layerpairs.keys():
                self.properties[label] = layermask[layer]
                layout.prop(self.properties,label,text=layerpairs[layer])
        

def register():
    pass


def unregister():
    pass


        